@@ -63,7 +63,7 @@ class Freebox(IPlugin):
 					# search position '|' dans rs['idx']	
 					# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
 					for rx in range (1, int(rs['idx_sec'])):
-						log.msg("idx  :  %s" % (int(rs['idx_sec']))
+						log.msg("idx  :  %s" % (int(rs['idx_sec'])))
 						log.msg("idx  :  %s" % (rs['idx']))
 						resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
 						log.msg("resp  :  %s" % (resp))
